Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1306)

Unified Diff: src/shared/platform_cmsis.cc

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/shared/platform_cmsis.h ('k') | src/shared/platform_linux.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/shared/platform_cmsis.cc
diff --git a/src/shared/platform_cmsis.cc b/src/shared/platform_cmsis.cc
index ea6f587fe25532ea61b1ccf709508841ffb382fc..1594b01d170ff75137fe39608f6a69385a705a53 100644
--- a/src/shared/platform_cmsis.cc
+++ b/src/shared/platform_cmsis.cc
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-#if defined(FLETCH_TARGET_OS_CMSIS)
+#if defined(DARTINO_TARGET_OS_CMSIS)
// We do not include platform_posix.h on purpose. That file
// should never be directly inported. platform.h is always
@@ -16,21 +16,21 @@
#include "src/shared/utils.h"
-namespace fletch {
+namespace dartino {
-osMailQId fletchMailQ;
+osMailQId dartinoMailQ;
-osMailQId GetFletchMailQ() {
- return fletchMailQ;
+osMailQId GetDartinoMailQ() {
+ return dartinoMailQ;
}
// Sends a message on the fletch osMailQ used by the event handler.
int SendMessageCmsis(uint32_t port_id, int64_t message) {
CmsisMessage *cmsisMessage =
- reinterpret_cast<CmsisMessage*>(osMailAlloc(fletchMailQ, 0));
+ reinterpret_cast<CmsisMessage*>(osMailAlloc(dartinoMailQ, 0));
cmsisMessage->port_id = port_id;
cmsisMessage->message = message;
- return osMailPut(GetFletchMailQ(), reinterpret_cast<void*>(cmsisMessage));
+ return osMailPut(GetDartinoMailQ(), reinterpret_cast<void*>(cmsisMessage));
}
static uint64 time_launch;
@@ -40,8 +40,8 @@ const uint32_t kMailQSize = 50;
void Platform::Setup() {
time_launch = GetMicroseconds();
- osMailQDef(fletch_queue, kMailQSize, CmsisMessage);
- fletchMailQ = osMailCreate(osMailQ(fletch_queue), NULL);
+ osMailQDef(dartino_queue, kMailQSize, CmsisMessage);
+ dartinoMailQ = osMailCreate(osMailQ(dartino_queue), NULL);
}
void Platform::TearDown() { }
@@ -196,6 +196,6 @@ bool VirtualMemory::Uncommit(uword address, int size) {
return false;
}
-} // namespace fletch
+} // namespace dartino
-#endif // defined(FLETCH_TARGET_OS_CMSIS)
+#endif // defined(DARTINO_TARGET_OS_CMSIS)
« no previous file with comments | « src/shared/platform_cmsis.h ('k') | src/shared/platform_linux.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -16,21 +16,21 @@
}
-// Sends a message on the fletch osMailQ used by the event handler.
+// Sends a message on the dartino osMailQ used by the event handler.
int SendMessageCmsis(uint32_t port_id, int64_t message) {
CmsisMessage *cmsisMessage =
This is Rietveld 408576698